@@ -359,17 +359,22 @@ def features_select(
     uid=None,
     mz=None,
     rt=None,
-    coherence=None,
-    inty=None,
     rt_delta=None,
-    iso=None,
-    iso_of=None,
-    has_MS2=None,
+    inty=None,
+    coherence=None,
     prominence_scaled=None,
     prominence=None,
     height_scaled=None,
     height=None,
+    iso=None,
+    iso_of=None,
+    has_MS2=None,
     adduct_group=None,
+    identified=None,
+    id_top_name=None,
+    id_top_class=None,
+    id_top_adduct=None,
+    id_top_score=None,
 ):
     """
     Select features based on specified criteria and return the filtered DataFrame.
@@ -389,6 +394,11 @@ def features_select(
         prominence: prominence filter (tuple for range, single value for minimum)
         height: height filter (tuple for range, single value for minimum)
         adduct_group: adduct group filter (single value for exact match, list of values for multiple groups, tuple for range, or None for all)
+        identified: filter for features with/without identification (bool: True for identified, False for unidentified)
+        id_top_name: filter by top identification name using regex (str for regex pattern, list of str for multiple patterns combined with OR)
+        id_top_class: filter by top identification class using regex (str for regex pattern, list of str for multiple patterns combined with OR)
+        id_top_adduct: filter by top identification adduct (str for exact match, list of str for multiple adducts)
+        id_top_score: filter by top identification score (tuple for range, single value for minimum)
     Returns:
         polars.DataFrame: Filtered features DataFrame
     """
@@ -600,6 +610,82 @@ def features_select(
                 f"Selected features by adduct_group. Features removed: {feats_len_before_filter - len(feats)}",
             )
 
+    if identified is not None:
+        feats_len_before_filter = len(feats)
+        if "id_top_name" not in feats.columns:
+            self.logger.warning("No identification data found in features.")
+        else:
+            if identified:
+                # Filter for features with identification (non-null id_top_name)
+                feats = feats.filter(pl.col("id_top_name").is_not_null())
+            else:
+                # Filter for features without identification (null id_top_name)
+                feats = feats.filter(pl.col("id_top_name").is_null())
+            self.logger.debug(
+                f"Selected features by identification presence. Features removed: {feats_len_before_filter - len(feats)}",
+            )
+
+    if id_top_name is not None:
+        feats_len_before_filter = len(feats)
+        if "id_top_name" not in feats.columns:
+            self.logger.warning("No id_top_name data found in features.")
+        else:
+            if isinstance(id_top_name, list):
+                # Use regex matching for each pattern in the list (OR logic)
+                pattern = "|".join(id_top_name)
+                feats = feats.filter(pl.col("id_top_name").str.contains(pattern))
+            else:
+                # Use regex matching for single pattern
+                feats = feats.filter(pl.col("id_top_name").str.contains(id_top_name))
+            self.logger.debug(
+                f"Selected features by id_top_name (regex). Features removed: {feats_len_before_filter - len(feats)}",
+            )
+
+    if id_top_class is not None:
+        feats_len_before_filter = len(feats)
+        if "id_top_class" not in feats.columns:
+            self.logger.warning("No id_top_class data found in features.")
+        else:
+            if isinstance(id_top_class, list):
+                # Use regex matching for each pattern in the list (OR logic)
+                pattern = "|".join(id_top_class)
+                feats = feats.filter(pl.col("id_top_class").str.contains(pattern))
+            else:
+                # Use regex matching for single pattern
+                feats = feats.filter(pl.col("id_top_class").str.contains(id_top_class))
+            self.logger.debug(
+                f"Selected features by id_top_class (regex). Features removed: {feats_len_before_filter - len(feats)}",
+            )
+
+    if id_top_adduct is not None:
+        feats_len_before_filter = len(feats)
+        if "id_top_adduct" not in feats.columns:
+            self.logger.warning("No id_top_adduct data found in features.")
+        else:
+            if isinstance(id_top_adduct, list):
+                feats = feats.filter(pl.col("id_top_adduct").is_in(id_top_adduct))
+            else:
+                feats = feats.filter(pl.col("id_top_adduct") == id_top_adduct)
+            self.logger.debug(
+                f"Selected features by id_top_adduct. Features removed: {feats_len_before_filter - len(feats)}",
+            )
+
+    if id_top_score is not None:
+        feats_len_before_filter = len(feats)
+        if "id_top_score" not in feats.columns:
+            self.logger.warning("No id_top_score data found in features.")
+        else:
+            if isinstance(id_top_score, tuple) and len(id_top_score) == 2:
+                min_score, max_score = id_top_score
+                feats = feats.filter(
+                    (pl.col("id_top_score") >= min_score) & (pl.col("id_top_score") <= max_score)
+                )
+            else:
+                feats = feats.filter(pl.col("id_top_score") >= id_top_score)
+            self.logger.debug(
+                f"Selected features by id_top_score. Features removed: {feats_len_before_filter - len(feats)}",
+            )
+
     if len(feats) == 0:
         self.logger.warning("No features remaining after applying selection criteria.")
     else:
