@@ -129,6 +129,16 @@ from masster.sample.helpers import get_eic
 from masster.sample.helpers import set_source
 from masster.sample.helpers import _recreate_feature_map
 from masster.sample.helpers import _get_feature_map
+from masster.sample.id import lib_load
+from masster.sample.id import identify
+from masster.sample.id import get_id
+from masster.sample.id import id_reset
+from masster.sample.id import lib_reset
+from masster.sample.id import lib_compare
+from masster.sample.id import lib_select
+from masster.sample.id import lib_filter
+from masster.sample.importers import import_oracle
+from masster.sample.importers import import_tima
 from masster.sample.load import chrom_extract
 from masster.sample.load import _index_file
 from masster.sample.load import load
@@ -145,6 +155,7 @@ from masster.sample.plot import plot_ms2_eic
 from masster.sample.plot import plot_ms2_q1
 from masster.sample.plot import plot_bpc
 from masster.sample.plot import plot_tic
+from masster.sample.plot import plot_ms2
 from masster.sample.plot import _handle_sample_plot_output
 from masster.sample.processing import _clean_features_df
 from masster.sample.processing import _features_deisotope
@@ -164,7 +175,9 @@ from masster.sample.save import export_chrom
 from masster.sample.save import export_dda_stats
 from masster.sample.save import export_features
 from masster.sample.save import export_mgf
-from masster.sample.save import export_xlsx
+from masster.sample.save import export_excel
+from masster.sample.save import export_csv
+from masster.sample.save import export_mztab
 from masster.sample.save import save
 
 
@@ -259,9 +272,10 @@ class Sample:
         # the polars data frame with MS1 level data
         self.ms1_df = pl.DataFrame()
 
-        # lightweight lib data for matching, targeted analyses, etc. > superseded by study methods
-        self.lib = None
-        self.lib_match = None
+        # identification DataFrames (lib_df and id_df)
+        self.lib_df = None  # library DataFrame (from masster.lib or CSV/JSON)
+        self.id_df = None   # identification results DataFrame
+        self._lib = None    # reference to Lib object if loaded
         self.chrom_df = None
 
         if params.filename is not None:
@@ -292,11 +306,25 @@ class Sample:
     update_parameters = update_parameters
     get_parameters_property = get_parameters_property
     set_parameters_property = set_parameters_property
+    # Identification methods from id.py
+    lib_load = lib_load
+    identify = identify
+    get_id = get_id
+    id_reset = id_reset
+    lib_reset = lib_reset
+    lib_compare = lib_compare
+    lib_select = lib_select
+    lib_filter = lib_filter
+    # Importers from importers.py
+    import_oracle = import_oracle
+    import_tima = import_tima
     export_features = export_features
-    export_xlsx = export_xlsx
+    export_excel = export_excel
+    export_csv = export_csv
     export_mgf = export_mgf
     export_chrom = export_chrom
     export_dda_stats = export_dda_stats
+    export_mztab = export_mztab
     plot_2d = plot_2d
     plot_2d_oracle = plot_2d_oracle
     plot_dda_stats = plot_dda_stats
@@ -308,6 +336,7 @@ class Sample:
     plot_ms2_q1 = plot_ms2_q1
     plot_bpc = plot_bpc
     plot_tic = plot_tic
+    plot_ms2 = plot_ms2
     _handle_sample_plot_output = _handle_sample_plot_output
     get_eic = get_eic
     get_feature = get_feature
