@@ -367,12 +367,14 @@ class SciexWiffData:
         "activation": "U",
     }
 
-    def __init__(self, centroided: bool = True) -> None:
+    def __init__(self, centroided: bool = True, sample_id: int = 0) -> None:
         """
         Parameters
         ----------
         centroided : bool, optional
             If peaks will be centroided after loading, by default True.
+        sample_id : int, optional
+            The ID of the sample to load, by default 0.
         """
         self.spectrum_df: pd.DataFrame = pd.DataFrame()
         self.peak_df: pd.DataFrame = pd.DataFrame()
@@ -392,7 +394,7 @@ class SciexWiffData:
         self.centroid_ppm = 20.0
         self.ignore_empty_scans = True
         self.keep_k_peaks_per_spec = 2000
-        self.sample_id = 0
+        self.sample_id = sample_id
 
     @property
     def raw_file_path(self) -> str:
@@ -572,6 +574,28 @@ def get_sample_names(filename: str) -> list[str]:
         return list(reader.sample_names)
 
 
+def count_samples(filename: str) -> int:
+    """
+    Count the number of samples in a WIFF file.
+
+    Parameters
+    ----------
+    filename : str
+        Path to the WIFF file
+
+    Returns
+    -------
+    int
+        Number of samples in the WIFF file
+    """
+    _wiffDataProvider = AnalystWiffDataProvider()
+    _wiff_file = AnalystDataProviderFactory.CreateBatch(filename, _wiffDataProvider)
+    sample_names = _wiff_file.GetSampleNames()
+    sample_names = [sample_name for sample_name in sample_names]
+    _wiffDataProvider.Close()
+    return len(sample_names)
+
+
 # Example usage and testing
 if __name__ == "__main__":
     print("Standalone Sciex WIFF reader implementation")
