@@ -14,8 +14,8 @@ Main class:
         consensus_select/filter/delete
     - Retrieval: get_consensus, get_chrom, get_samples, get_*_stats, get_*_matrix
     - Plotting: plot_alignment, plot_samples_pca/umap/2d, plot_tic/bpc/eic, plot_chrom,
-        plot_rt_correction, plot_consensus_2d/stats
-    - Export: export_mgf, export_mztab, export_xlsx, export_parquet
+        plot_rt_correction, plot_consensus_2d/stats, plot_heatmap
+    - Export: export_mgf, export_mztab, export_excel, export_parquet
     - Identification: lib_load, identify, get_id, id_reset, lib_reset
     - Parameters: get/update parameters, update_history
 
@@ -96,6 +96,8 @@ from masster.study.plot import plot_bpc
 from masster.study.plot import plot_tic
 from masster.study.plot import plot_eic
 from masster.study.plot import plot_rt_correction
+from masster.study.plot import plot_heatmap
+from masster.study.plot import plot_ms2
 from masster.study.processing import align
 from masster.study.merge import merge
 from masster.study.processing import integrate
@@ -108,8 +110,8 @@ from masster.study.parameters import update_parameters
 from masster.study.parameters import get_parameters_property
 from masster.study.parameters import set_parameters_property
 from masster.study.save import save, save_consensus, save_samples
-from masster.study.export import export_mgf, export_mztab, export_xlsx, export_parquet
-from masster.study.id import lib_load, identify, get_id, id_reset, lib_reset, _get_adducts
+from masster.study.export import export_mgf, export_mztab, export_excel, export_parquet, export_csv
+from masster.study.id import lib_load, identify, get_id, id_reset, lib_reset, lib_compare, lib_select, lib_filter, _get_adducts
 from masster.study.importers import import_oracle
 
 from masster.logger import MassterLogger
@@ -401,9 +403,6 @@ class Study:
     # Backward compatibility aliases for renamed methods
     set_folder = set_study_folder
     set_source = set_samples_source
-    # sample_color = set_samples_color
-    # get_sample = get_samples
-    # load_features = _load_features
     store_history = update_history
 
     # === Data Compression and Storage ===
@@ -429,6 +428,8 @@ class Study:
     plot_rt_correction = plot_rt_correction
     plot_tic = plot_tic
     plot_eic = plot_eic
+    plot_heatmap = plot_heatmap
+    plot_ms2 = plot_ms2
 
     # === Analysis Operations ===
     analyze_umap = analyze_umap
@@ -436,8 +437,9 @@ class Study:
     # === Export Operations ===
     export_mgf = export_mgf
     export_mztab = export_mztab
-    export_xlsx = export_xlsx
+    export_excel = export_excel
     export_parquet = export_parquet
+    export_csv = export_csv
 
     # === Identification and Library Matching ===
     lib_load = lib_load
@@ -454,6 +456,9 @@ class Study:
     reset_id = id_reset
     lib_reset = lib_reset
     reset_lib = lib_reset
+    lib_compare = lib_compare
+    lib_select = lib_select
+    lib_filter = lib_filter
 
     # === Oracle Import Operations ===
     import_oracle = import_oracle
